@@ -1,4 +1,5 @@
-import config
+from scripts import config
+from scripts import version
 
 def generate_pkg_config_file():
         f = open('./build/xmlbird.pc', 'w+')
@@ -9,7 +10,7 @@ libdir=${exec_prefix}/lib
 
 Name: xmlbird
 Description: XML parser
-Version: 1.0.0
+Version: """ + version.XMLBIRD_VERSION + """
 Cflags: -I${includedir}
 Libs: -L${libdir} -lxmlbird
-""")
\ No newline at end of file
+""")
